@@ -1,5 +1,5 @@
 #include "service.h"
-#include <MauiKit3/FileBrowsing/downloader.h>
+#include <MauiKit4/FileBrowsing/downloader.h>
 
 Service::Service(QObject *parent)
     : QObject(parent)
@@ -11,6 +11,21 @@ void Service::set(const PULPO::REQUEST &request)
     this->request = request;
 }
 
+void Service::parseArtist(const QByteArray &)
+{
+
+}
+
+void Service::parseAlbum(const QByteArray &)
+{
+
+}
+
+void Service::parseTrack(const QByteArray &)
+{
+
+}
+
 void Service::parse(const QByteArray &array)
 {
     switch (this->request.ontology) {
@@ -31,10 +46,10 @@ void Service::retrieve(const QString &url, const QMap<QString, QString> &headers
     if (!url.isEmpty()) {
         auto downloader = new FMH::Downloader;
         connect(downloader, &FMH::Downloader::dataReady, [this, downloader](QByteArray array) {
-            emit this->arrayReady(array);
+            Q_EMIT this->arrayReady(array);
             downloader->deleteLater();
         });
-        downloader->getArray(url, headers);
+        downloader->getArray(QUrl(url), headers);
     }
 }
 
